@@ -42,17 +42,20 @@ import org.jboss.as.controller.descriptions.ModelDescriptionConstants;
 import org.jboss.as.controller.operations.common.Util;
 import org.jboss.as.ejb3.subsystem.EJB3Extension;
 import org.jboss.as.ejb3.subsystem.EJB3SubsystemModel;
+import org.jboss.as.network.NetworkUtils;
 import org.jboss.as.remoting.RemotingExtension;
 import org.jboss.dmr.ModelNode;
 import org.jboss.logging.Logger;
 
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.ADD;
+import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.ALLOW_RESOURCE_SERVICE_RESTART;
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.COMPOSITE;
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.CORE_SERVICE;
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.HOST;
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.MANAGEMENT;
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.NAME;
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.OP;
+import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.OPERATION_HEADERS;
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.OP_ADDR;
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.PORT;
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.READ_ATTRIBUTE_OPERATION;
@@ -71,7 +74,6 @@ import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.VAL
 import static org.jboss.as.controller.descriptions.ModelDescriptionConstants.WRITE_ATTRIBUTE_OPERATION;
 import static org.jboss.as.test.integration.management.util.ModelUtil.createOpNode;
 
-
 /**
  * @author Jaikiran Pai
  */
@@ -226,6 +228,8 @@ public class EJBManagementUtil {
             final PathAddress address = PathAddress.pathAddress(PathElement.pathElement(SOCKET_BINDING_GROUP, socketGroupName),
                     PathElement.pathElement(ModelDescriptionConstants.LOCAL_DESTINATION_OUTBOUND_SOCKET_BINDING, outboundSocketName));
             outboundSocketRemoveOperation.get(OP_ADDR).set(address.toModelNode());
+            outboundSocketRemoveOperation.get(OPERATION_HEADERS, ALLOW_RESOURCE_SERVICE_RESTART).set(true);
+
             // execute the remove operation
             execute(modelControllerClient, outboundSocketRemoveOperation);
 
@@ -374,6 +378,70 @@ public class EJBManagementUtil {
         }
     }
 
+    public static void editEntityBeanInstancePool(final ModelControllerClient controllerClient, final String poolName, final boolean optimisticLocking) {
+        try {
+            // /subsystem=ejb3
+            final PathAddress ejb3SubsystemAddress = PathAddress.pathAddress(PathElement.pathElement(SUBSYSTEM, EJB3Extension.SUBSYSTEM_NAME));
+
+            // /subsystem=ejb3:write-attribute(name="default-entity-bean-instance-pool", value=<poolName>)
+            final ModelNode defaultEntityBeanInstancePool = new ModelNode();
+            // set the operation
+            defaultEntityBeanInstancePool.get(OP).set(WRITE_ATTRIBUTE_OPERATION);
+            // set the address
+            defaultEntityBeanInstancePool.get(OP_ADDR).set(ejb3SubsystemAddress.toModelNode());
+            // setup the parameters for the write attribute operation
+            defaultEntityBeanInstancePool.get(NAME).set(EJB3SubsystemModel.DEFAULT_ENTITY_BEAN_INSTANCE_POOL);
+            defaultEntityBeanInstancePool.get(VALUE).set(poolName);
+            // execute the operation
+            execute(controllerClient, defaultEntityBeanInstancePool);
+
+            // /subsystem=ejb3:write-attribute(name="default-entity-bean-optimistic-locking", value=<optimisticLocking>)
+            final ModelNode defaultEntityBeanOptimisticLocking = new ModelNode();
+            // set the operation
+            defaultEntityBeanOptimisticLocking.get(OP).set(WRITE_ATTRIBUTE_OPERATION);
+            // set the address
+            defaultEntityBeanOptimisticLocking.get(OP_ADDR).set(ejb3SubsystemAddress.toModelNode());
+            // setup the parameters for the write attribute operation
+            defaultEntityBeanOptimisticLocking.get(NAME).set(EJB3SubsystemModel.DEFAULT_ENTITY_BEAN_OPTIMISTIC_LOCKING);
+            defaultEntityBeanOptimisticLocking.get(VALUE).set(optimisticLocking);
+            // execute the operation
+            execute(controllerClient, defaultEntityBeanOptimisticLocking);
+        } catch (IOException ioe) {
+            throw new RuntimeException(ioe);
+        }
+    }
+
+    public static void undefineEntityBeanInstancePool(final ModelControllerClient controllerClient) {
+        try {
+            // /subsystem=ejb3
+            final PathAddress ejb3SubsystemAddress = PathAddress.pathAddress(PathElement.pathElement(SUBSYSTEM, EJB3Extension.SUBSYSTEM_NAME));
+
+            // /subsystem=ejb3:undefine-attribute(name="default-entity-bean-instance-pool")
+            final ModelNode defaultEntityBeanInstancePool = new ModelNode();
+            // set the operation
+            defaultEntityBeanInstancePool.get(OP).set(UNDEFINE_ATTRIBUTE_OPERATION);
+            // set the address
+            defaultEntityBeanInstancePool.get(OP_ADDR).set(ejb3SubsystemAddress.toModelNode());
+            // setup the parameters for the undefine attribute operation
+            defaultEntityBeanInstancePool.get(NAME).set(EJB3SubsystemModel.DEFAULT_ENTITY_BEAN_INSTANCE_POOL);
+            // execute the operation
+            execute(controllerClient, defaultEntityBeanInstancePool);
+
+            // /subsystem=ejb3:undefine-attribute(name="default-entity-bean-optimistic-locking")
+            final ModelNode defaultEntityBeanOptimisticLocking = new ModelNode();
+            // set the operation
+            defaultEntityBeanOptimisticLocking.get(OP).set(UNDEFINE_ATTRIBUTE_OPERATION);
+            // set the address
+            defaultEntityBeanOptimisticLocking.get(OP_ADDR).set(ejb3SubsystemAddress.toModelNode());
+            // setup the parameters for the undefine attribute operation
+            defaultEntityBeanOptimisticLocking.get(NAME).set(EJB3SubsystemModel.DEFAULT_ENTITY_BEAN_OPTIMISTIC_LOCKING);
+            // execute the operation
+            execute(controllerClient, defaultEntityBeanOptimisticLocking);
+        } catch (IOException ioe) {
+            throw new RuntimeException(ioe);
+        }
+    }
+
     public static void enablePassByValueForRemoteInterfaceInvocations(ManagementClient managementClient) {
         editPassByValueForRemoteInterfaceInvocations(managementClient, true);
     }
@@ -449,7 +517,7 @@ public class EJBManagementUtil {
     private static ModelNode execute(final ModelControllerClient modelControllerClient, final ModelNode operation) throws IOException {
         final ModelNode result = modelControllerClient.execute(operation);
         if (result.hasDefined(ClientConstants.OUTCOME) && ClientConstants.SUCCESS.equals(result.get(ClientConstants.OUTCOME).asString())) {
-            logger.info("Operation " + operation.toString() + " successful");
+            //logger.info("Operation " + operation.toString() + " successful");
             return result;
         } else if (result.hasDefined(ClientConstants.FAILURE_DESCRIPTION)) {
             final String failureDesc = result.get(ClientConstants.FAILURE_DESCRIPTION).toString();
@@ -482,7 +550,7 @@ public class EJBManagementUtil {
             }
             if (qualifiedHostName == null) {
                 try {
-                    qualifiedHostName = InetAddress.getLocalHost().getHostName();
+                    qualifiedHostName = NetworkUtils.canonize(InetAddress.getLocalHost().getHostName());
                 } catch (UnknownHostException e) {
                     qualifiedHostName = null;
                 }
